@@ -136,6 +136,7 @@ typedef enum {
 	ACTION_CHANGED_SIGNAL,
 	DUMMY_SUCCESS_SIGNAL,
 	EJECT_FAILURE_SIGNAL,
+	BLANK_FAILURE_SIGNAL,
 	INSTALL_MISSING_SIGNAL,
 	LAST_SIGNAL
 } BraseroBurnSignalType;
@@ -191,7 +192,9 @@ brasero_burn_log (BraseroBurn *burn,
 }
 
 static BraseroBurnResult
-brasero_burn_emit_signal (BraseroBurn *burn, guint signal, BraseroBurnResult default_answer)
+brasero_burn_emit_signal (BraseroBurn *burn,
+                          guint signal,
+                          BraseroBurnResult default_answer)
 {
 	GValue instance_and_params;
 	GValue return_value;
@@ -229,14 +232,14 @@ brasero_burn_action_changed_real (BraseroBurn *burn,
 		               0,
 		               1.0,
 		               1.0,
-		               -1);
+		               -1L);
 	else if (action == BRASERO_BURN_ACTION_EJECTING)
 		g_signal_emit (burn,
 			       brasero_burn_signals [PROGRESS_CHANGED_SIGNAL],
 			       0,
 			       -1.0,
 			       -1.0,
-			       -1);
+			       -1L);
 }
 
 static gboolean
@@ -540,7 +543,7 @@ brasero_burn_ask_for_dest_media (BraseroBurn *burn,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_OUTPUT_NONE,
-				     _("No burner specified"));
+				     "%s", _("No burner specified"));
 			return BRASERO_BURN_ERR;
 		}
 	}
@@ -580,7 +583,7 @@ brasero_burn_lock_src_media (BraseroBurn *burn,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("No source drive specified"));
+			     "%s", _("No source drive specified"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -672,7 +675,7 @@ brasero_burn_lock_rewritable_media (BraseroBurn *burn,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_OUTPUT_NONE,
-			     _("No burner specified"));
+			     "%s", _("No burner specified"));
 		return BRASERO_BURN_NOT_SUPPORTED;
 	}
 
@@ -689,7 +692,7 @@ brasero_burn_lock_rewritable_media (BraseroBurn *burn,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_MEDIUM_NOT_REWRITABLE,
-			     _("The drive has no rewriting capabilities"));
+			     "%s", _("The drive has no rewriting capabilities"));
 		return BRASERO_BURN_NOT_SUPPORTED;
 	}
 
@@ -755,7 +758,7 @@ brasero_burn_lock_dest_media (BraseroBurn *burn,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_OUTPUT_NONE,
-			     _("No burner specified"));
+			     "%s", _("No burner specified"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -764,7 +767,7 @@ brasero_burn_lock_dest_media (BraseroBurn *burn,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("The drive cannot burn"));
+			     "%s", _("The drive cannot burn"));
 		BRASERO_BURN_NOT_SUPPORTED_LOG (burn);
 	}
 
@@ -1346,7 +1349,7 @@ start:
 				       0,
 				       1.0,
 				       1.0,
-				       -1);
+				       -1L);
 		}
 		return BRASERO_BURN_OK;
 	}
@@ -1408,7 +1411,8 @@ start:
 		goto start;
 	}
 	else if (error_code == BRASERO_BURN_ERROR_DISK_SPACE
-	     ||  error_code == BRASERO_BURN_ERROR_PERMISSION) {
+	     ||  error_code == BRASERO_BURN_ERROR_PERMISSION
+	     ||  error_code == BRASERO_BURN_ERROR_TMP_DIRECTORY) {
 		gboolean is_temp;
 
 		/* That's an imager (outputs an image to the disc) so that means
@@ -1519,7 +1523,7 @@ start:
 			       0,
 			       1.0,
 			       1.0,
-			       -1);
+			       -1L);
 		return BRASERO_BURN_OK;
 	}
 
@@ -1701,12 +1705,15 @@ brasero_burn_list_missing (BraseroPluginErrorType type,
 {
 	GString *string = user_data;
 
-	if (type == BRASERO_PLUGIN_ERROR_MISSING_APP) {
+	if (type == BRASERO_PLUGIN_ERROR_MISSING_APP ||
+	    type == BRASERO_PLUGIN_ERROR_SYMBOLIC_LINK_APP ||
+	    type == BRASERO_PLUGIN_ERROR_WRONG_APP_VERSION) {
 		g_string_append_c (string, '\n');
 		/* Translators: %s is the name of a missing application */
 		g_string_append_printf (string, _("%s (application)"), detail);
 	}
-	else if (type == BRASERO_PLUGIN_ERROR_MISSING_LIBRARY) {
+	else if (type == BRASERO_PLUGIN_ERROR_MISSING_LIBRARY ||
+	         type == BRASERO_PLUGIN_ERROR_LIBRARY_VERSION) {
 		g_string_append_c (string, '\n');
 		/* Translators: %s is the name of a missing library */
 		g_string_append_printf (string, _("%s (library)"), detail);
@@ -1747,7 +1754,7 @@ brasero_burn_check_session_consistency (BraseroBurn *burn,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("There is no track to burn"));
+			     "%s", _("There is no track to burn"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -1812,7 +1819,7 @@ brasero_burn_check_session_consistency (BraseroBurn *burn,
 				g_set_error (error,
 					     BRASERO_BURN_ERROR,
 					     BRASERO_BURN_ERROR_GENERAL,
-					     _("Merging data is impossible with this disc"));
+					     "%s", _("Merging data is impossible with this disc"));
 				return BRASERO_BURN_ERR;
 			}
 			/* No need to tell the user burnproof is not supported
@@ -1861,7 +1868,7 @@ brasero_burn_check_session_consistency (BraseroBurn *burn,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_MISSING_APP_AND_PLUGIN,
-				     string->str);
+				     "%s", string->str);
 
 			g_string_free (string, TRUE);
 		}
@@ -1874,28 +1881,38 @@ brasero_burn_check_session_consistency (BraseroBurn *burn,
 
 static BraseroBurnResult
 brasero_burn_check_data_loss (BraseroBurn *burn,
+                              BraseroTrackType *temp_output,
                               GError **error)
 {
 	BraseroMedia media;
 	BraseroBurnFlag flags;
 	BraseroTrackType *input;
 	BraseroBurnResult result;
-	BraseroTrackType *output;
 	BraseroBurnPrivate *priv = BRASERO_BURN_PRIVATE (burn);
 
-	output = brasero_track_type_new ();
-	brasero_burn_session_get_output_type (priv->session, output);
-	if (!brasero_track_type_get_has_medium (output)) {
-		brasero_track_type_free (output);
-		return BRASERO_BURN_OK;
-	}
+	if (!temp_output) {
+		BraseroTrackType *output;
 
-	flags = brasero_burn_session_get_flags (priv->session);
-	media = brasero_track_type_get_medium_type (output);
-	brasero_track_type_free (output);
+		output = brasero_track_type_new ();
+		brasero_burn_session_get_output_type (priv->session, output);
+		if (!brasero_track_type_get_has_medium (output)) {
+			brasero_track_type_free (output);
+			return BRASERO_BURN_OK;
+		}
+
+		media = brasero_track_type_get_medium_type (output);
+		brasero_track_type_free (output);
+	}
+	else {
+		if (!brasero_track_type_get_has_medium (temp_output))
+			return BRASERO_BURN_OK;
+
+		media = brasero_track_type_get_medium_type (temp_output);
+	}
 
 	input = brasero_track_type_new ();
 	brasero_burn_session_get_input_type (priv->session, input);
+	flags = brasero_burn_session_get_flags (priv->session);
 
 	if (media & (BRASERO_MEDIUM_HAS_DATA|BRASERO_MEDIUM_HAS_AUDIO)) {
 		if (flags & BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE) {
@@ -2047,10 +2064,9 @@ brasero_burn_run_tasks (BraseroBurn *burn,
 		return result;
 	}
 
-	/* performed some additional tests that can
-	 * only be performed at this point. They are
-	 * mere warnings. */
-	result = brasero_burn_check_data_loss (burn, error);
+	/* performed some additional tests that can only be performed at this
+	 * point. They are mere warnings. */
+	result = brasero_burn_check_data_loss (burn, temp_output, error);
 	if (result != BRASERO_BURN_OK) {
 		brasero_burn_session_pop_settings (priv->session);
 		return result;
@@ -2126,9 +2142,13 @@ brasero_burn_run_tasks (BraseroBurn *burn,
 
 				if (session_sec > medium_sec) {
 					BRASERO_BURN_LOG ("Not enough space on medium %"G_GOFFSET_FORMAT"/%"G_GOFFSET_FORMAT, session_sec, medium_sec);
-					result = brasero_burn_reload_dest_media (burn,  BRASERO_BURN_ERROR_MEDIUM_SPACE, error);
-					if (result != BRASERO_BURN_OK)
-						break;
+					result = brasero_burn_reload_dest_media (burn,
+					                                         BRASERO_BURN_ERROR_MEDIUM_SPACE,
+					                                         error);
+					if (result == BRASERO_BURN_OK)
+						result = BRASERO_BURN_RETRY;
+
+					break;
 				}
 			}
 			brasero_track_type_free (type);
@@ -2140,8 +2160,29 @@ brasero_burn_run_tasks (BraseroBurn *burn,
 			 * data on it when we get to the real recording. */
 			if (erase_allowed) {
 				result = brasero_burn_run_eraser (burn, error);
-				if (result != BRASERO_BURN_OK)
+				if (result == BRASERO_BURN_CANCEL)
+					return result;
+
+				/* If the erasing process did not work then do
+				 * not fail and cancel the entire session but
+				 * ask the user if he wants to insert another
+				 * disc instead. */
+				if (result != BRASERO_BURN_OK) {
+					BraseroBurnResult local_result;
+
+					local_result = brasero_burn_emit_signal (burn,
+					                                         BLANK_FAILURE_SIGNAL,
+					                                         BRASERO_BURN_ERR);
+					if (local_result == BRASERO_BURN_OK) {
+						local_result = brasero_burn_reload_dest_media (burn,
+						                                               BRASERO_BURN_ERROR_NONE,
+						                                               NULL);
+						if (local_result == BRASERO_BURN_OK)
+							result = BRASERO_BURN_RETRY;
+					}
+
 					break;
+				}
 
 				/* Since we blanked/formatted we need to recheck the burn 
 				 * flags with the new medium type as some flags could have
@@ -2293,7 +2334,7 @@ brasero_burn_check_real (BraseroBurn *self,
 			       0,
 			       1.0,
 			       1.0,
-			       -1);
+			       -1L);
 
 		g_object_unref (priv->task);
 		priv->task = NULL;
@@ -2548,7 +2589,7 @@ brasero_burn_check (BraseroBurn *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Only one track at a time can be checked"));
+			     "%s", _("Only one track at a time can be checked"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -2607,7 +2648,7 @@ brasero_burn_same_src_dest_image (BraseroBurn *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("No format for the temporary image could be found"));
+			     "%s", _("No format for the temporary image could be found"));
 		return result;
 	}
 
@@ -2818,7 +2859,7 @@ end:
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("An internal error occurred"));
+			     "%s", _("An internal error occurred"));
 	}
 
 	if (result == BRASERO_BURN_CANCEL) {
@@ -2917,9 +2958,9 @@ brasero_burn_blank (BraseroBurn *burn,
 		goto end;
 
 	result = brasero_burn_blank_real (burn, &ret_error);
-	while (result == BRASERO_BURN_ERR
-	&&     ret_error
-	&&     ret_error->code == BRASERO_BURN_ERROR_MEDIUM_NOT_REWRITABLE) {
+	while (result == BRASERO_BURN_ERR &&
+	       ret_error &&
+	       ret_error->code == BRASERO_BURN_ERROR_MEDIUM_NOT_REWRITABLE) {
 		g_error_free (ret_error);
 		ret_error = NULL;
 
@@ -3158,7 +3199,17 @@ brasero_burn_class_init (BraseroBurnClass *klass)
 			      brasero_marshal_INT__OBJECT,
 			      G_TYPE_INT, 1,
 		              BRASERO_TYPE_DRIVE);
-        brasero_burn_signals [INSTALL_MISSING_SIGNAL] =
+        brasero_burn_signals [BLANK_FAILURE_SIGNAL] =
+		g_signal_new ("blank_failure",
+			      G_TYPE_FROM_CLASS (klass),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (BraseroBurnClass,
+					       blank_failure),
+			      NULL, NULL,
+			      brasero_marshal_INT__VOID,
+			      G_TYPE_INT, 0,
+		              G_TYPE_NONE);
+	brasero_burn_signals [INSTALL_MISSING_SIGNAL] =
 		g_signal_new ("install_missing",
 			      G_TYPE_FROM_CLASS (klass),
 			      G_SIGNAL_RUN_LAST,
