@@ -30,8 +30,6 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
-#include <gconf/gconf-client.h>
-
 #include <libnautilus-extension/nautilus-menu-provider.h>
 #include <libnautilus-extension/nautilus-location-widget-provider.h>
 
@@ -57,14 +55,13 @@
 
 #include "nautilus-burn-bar.h"
 
-#include "brasero-project-name.h"
-
 #include "brasero-misc.h"
 
 #include "brasero-media-private.h"
 #include "burn-debug.h"
 
-#define BURN_URI "burn:///"
+#define BURN_URI	"burn:///"
+#define WINDOW_KEY      "NautilusWindow"
 
 #define NAUTILUS_TYPE_DISC_BURN  (nautilus_disc_burn_get_type ())
 #define NAUTILUS_DISC_BURN(o)    (G_TYPE_CHECK_INSTANCE_CAST ((o), NAUTILUS_TYPE_DISC_BURN, NautilusDiscBurn))
@@ -94,6 +91,9 @@ struct _NautilusDiscBurnPrivate
         guint         empty_update_id;
 
         GSList       *widget_list;
+
+	gchar        *title;
+	gchar        *icon;
 };
 
 static GType nautilus_disc_burn_get_type      (void);
@@ -104,21 +104,25 @@ static GObjectClass *parent_class;
 //#define DEBUG_PRINT(format_MACRO,...)           g_print (format_MACRO, ##__VA_ARGS__);
 #define DEBUG_PRINT(format_MACRO,...)             
 
+#define BRASERO_SCHEMA				"org.gnome.brasero"
+#define BRASERO_PROPS_NAUTILUS_EXT_DEBUG	"nautilus-extension-debug"
+
 /* do not call brasero_*_start() at nautilus startup, they are very expensive;
  * lazily initialize those instead */
 static void
-ensure_initialized()
+ensure_initialized ()
 {
 	static gboolean initialized = FALSE;
-	GConfClient *client;
 
 	if (!initialized) {
-		client = gconf_client_get_default ();
-		if (gconf_client_get_bool (client, "/apps/brasero/nautilus-extension-debug", NULL)) {
-		    brasero_media_library_set_debug (TRUE);
-		    brasero_burn_library_set_debug (TRUE);
+		GSettings *settings;
+
+		settings = g_settings_new (BRASERO_SCHEMA);
+		if (g_settings_get_boolean (settings, BRASERO_PROPS_NAUTILUS_EXT_DEBUG)) {
+			brasero_media_library_set_debug (TRUE);
+			brasero_burn_library_set_debug (TRUE);
 		}
-		g_object_unref (client);
+		g_object_unref (settings);
 
 		brasero_media_library_start ();
 		brasero_burn_library_start (NULL, NULL);
@@ -134,9 +138,10 @@ launch_brasero_on_window_session (BraseroSessionCfg	*session,
 				  GtkWidget		*options,
 				  GtkWindow		*window)
 {
+	gboolean		 success;
+	GtkResponseType		 result;
 	const gchar		*icon_name;
 	GtkWidget		*dialog;
-	GtkResponseType		 result;
 
 	/* Get the icon for the window */
 	if (window)
@@ -146,7 +151,6 @@ launch_brasero_on_window_session (BraseroSessionCfg	*session,
 
 	/* run option dialog */
 	dialog = brasero_burn_options_new (session);
-
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), icon_name);
 
 	if (dialog_title)
@@ -177,11 +181,11 @@ launch_brasero_on_window_session (BraseroSessionCfg	*session,
 	gtk_window_present (GTK_WINDOW (dialog));
 
 	if (result == GTK_RESPONSE_OK)
-		brasero_burn_dialog_run (BRASERO_BURN_DIALOG (dialog),
-					 BRASERO_BURN_SESSION (session));
+		success = brasero_burn_dialog_run (BRASERO_BURN_DIALOG (dialog),
+		                                   BRASERO_BURN_SESSION (session));
 	else
-		brasero_burn_dialog_run_multi (BRASERO_BURN_DIALOG (dialog),
-					       BRASERO_BURN_SESSION (session));
+		success = brasero_burn_dialog_run_multi (BRASERO_BURN_DIALOG (dialog),
+		                                         BRASERO_BURN_SESSION (session));
 
 	gtk_widget_destroy (dialog);
 }
@@ -244,56 +248,39 @@ nautilus_disc_burn_is_empty (GtkWindow *toplevel)
 }
 
 static void
-brasero_session_name_changed (BraseroProjectName *project_name,
-                              BraseroBurnSession *session)
-{
-	const gchar *label;
-
-	label = gtk_entry_get_text (GTK_ENTRY (project_name));
-	brasero_burn_session_set_label (session, label);
-}
-
-static void
-write_activate (GtkWindow *toplevel)
+write_activate (NautilusDiscBurn *burn,
+                GtkWindow *toplevel)
 {
 	BraseroTrackDataCfg	*track;
 	BraseroSessionCfg	*session;
-	GtkWidget 		*name_options;
-	GtkWidget		*options;
-	gchar			*string;
 
 	if (nautilus_disc_burn_is_empty (toplevel))
 		return;
 
+	ensure_initialized ();
+
 	track = brasero_track_data_cfg_new ();
 	brasero_track_data_cfg_add (track, BURN_URI, NULL);
 
+	if (burn->priv->icon)
+		brasero_track_data_cfg_set_icon (BRASERO_TRACK_DATA_CFG (track),
+		                                 burn->priv->icon,
+		                                 NULL);
+
 	session = brasero_session_cfg_new ();
 	brasero_burn_session_add_track (BRASERO_BURN_SESSION (session),
 					BRASERO_TRACK (track),
 					NULL);
 	g_object_unref (track);
 
-	/* add name widget here to set the label of the volume */
-	name_options = brasero_project_name_new (NULL);
-	brasero_project_name_set_session (BRASERO_PROJECT_NAME (name_options),
-					  BRASERO_BURN_SESSION (session));
-	g_signal_connect (name_options,
-	                  "name-changed",
-	                  G_CALLBACK (brasero_session_name_changed),
-	                  session);
-
-	string = g_strdup_printf ("<b>%s</b>", _("Disc name"));
-	options = brasero_utils_pack_properties (string,
-						 name_options,
-						 NULL);
-	g_free (string);
-	gtk_widget_show_all (options);
+	if (burn->priv->title)
+		brasero_burn_session_set_label (BRASERO_BURN_SESSION (session),
+		                                burn->priv->title);
 
 	/* NOTE: set the disc we're handling */
 	launch_brasero_on_window_session (session,
 	                                  _("CD/DVD Creator"),
-	                                  options,
+	                                  NULL,
 	                                  toplevel);
 
 	/* cleanup */
@@ -304,7 +291,8 @@ static void
 write_activate_cb (NautilusMenuItem *item,
                    gpointer          user_data)
 {
-	write_activate (GTK_WINDOW (user_data));
+	write_activate (NAUTILUS_DISC_BURN (user_data),
+	                GTK_WINDOW (g_object_get_data (G_OBJECT (item), WINDOW_KEY)));
 }
 
 static void
@@ -433,6 +421,8 @@ check_disc_activate_cb (NautilusMenuItem *item,
 {
 	BraseroSumDialog *dialog;
 
+	ensure_initialized ();
+
 	dialog = brasero_sum_dialog_new ();
 	tool_dialog_run (BRASERO_TOOL_DIALOG (dialog),
 			 GTK_WINDOW (user_data),
@@ -504,7 +494,12 @@ drive_is_cd_device (GDrive *gdrive)
 
         DEBUG_PRINT ("Got device: %s\n", device);
 
-        monitor = brasero_medium_monitor_get_default ();
+	/* FIXME: since we call the monitor, the library should be initialized.
+	 * To avoid all the initializing we'll be able to use the new GIO API
+	 * (#594649 -  Have a way to detect optical drives) */
+	ensure_initialized();
+
+	monitor = brasero_medium_monitor_get_default ();
         drive = brasero_medium_monitor_get_drive (monitor, device);
         g_object_unref (monitor);
         g_free (device);
@@ -620,7 +615,10 @@ nautilus_disc_burn_get_file_items (NautilusMenuProvider *provider,
 		BraseroMedia		 media;
 		BraseroTrackType	*type;
 
-		ensure_initialized();
+		/* Reminder: the following is not needed since it is already 
+		 * called in drive_is_cd_device ().
+		 * ensure_initialized();
+		 */
 
                 device_path = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
 		monitor = brasero_medium_monitor_get_default ();
@@ -717,9 +715,10 @@ nautilus_disc_burn_get_background_items (NautilusMenuProvider *provider,
                                                _("_Write to Disc…"),
                                                _("Write contents to a CD or DVD"),
                                                "brasero");
+		g_object_set_data (G_OBJECT (item), WINDOW_KEY, window);
                 g_signal_connect (item, "activate",
                                   G_CALLBACK (write_activate_cb),
-                                  window);
+                                  NAUTILUS_DISC_BURN (provider));
                 items = g_list_append (items, item);
 
                 g_object_set (item, "sensitive", ! NAUTILUS_DISC_BURN (provider)->priv->empty, NULL);
@@ -754,7 +753,26 @@ static void
 bar_activated_cb (NautilusDiscBurnBar	*bar,
                   gpointer		 user_data)
 {
-	write_activate (GTK_WINDOW (user_data));
+	write_activate (NAUTILUS_DISC_BURN (user_data),
+	                GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (bar))));
+}
+
+static void
+title_changed_cb (NautilusDiscBurnBar	*bar,
+                  NautilusDiscBurn	*burn)
+{
+	if (burn->priv->title)
+		g_free (burn->priv->title);
+	burn->priv->title = g_strdup (nautilus_disc_burn_bar_get_title (bar));
+}
+
+static void
+icon_changed_cb (NautilusDiscBurnBar	*bar,
+                 NautilusDiscBurn	*burn)
+{
+	if (burn->priv->icon)
+		g_free (burn->priv->icon);
+	burn->priv->icon = g_strdup (nautilus_disc_burn_bar_get_icon (bar));
 }
 
 static void
@@ -791,12 +809,21 @@ nautilus_disc_burn_get_location_widget (NautilusLocationWidgetProvider *iface,
                 burn = NAUTILUS_DISC_BURN (iface);
 
                 bar = nautilus_disc_burn_bar_new ();
-
+		nautilus_disc_burn_bar_set_title (NAUTILUS_DISC_BURN_BAR (bar),
+		                                  burn->priv->title);
+		nautilus_disc_burn_bar_set_icon (NAUTILUS_DISC_BURN_BAR (bar),
+		                                 burn->priv->icon);
                 sense_widget (burn, nautilus_disc_burn_bar_get_button (NAUTILUS_DISC_BURN_BAR (bar)));
 
                 g_signal_connect (bar, "activate",
                                   G_CALLBACK (bar_activated_cb),
-                                  window);
+                                  burn);
+		g_signal_connect (bar, "title-changed",
+		                  G_CALLBACK (title_changed_cb),
+		                  burn);
+		g_signal_connect (bar, "icon-changed",
+		                  G_CALLBACK (icon_changed_cb),
+		                  burn);
 
                 gtk_widget_show (bar);
 
@@ -933,6 +960,16 @@ nautilus_disc_burn_finalize (GObject *object)
 
         g_return_if_fail (burn->priv != NULL);
 
+	if (burn->priv->icon) {
+		g_free (burn->priv->icon);
+		burn->priv->icon = NULL;
+	}
+
+	if (burn->priv->title) {
+		g_free (burn->priv->title);
+		burn->priv->title = NULL;
+	}
+
         if (burn->priv->empty_update_id > 0) {
                 g_source_remove (burn->priv->empty_update_id);
         }
