@@ -904,6 +904,7 @@ brasero_local_track_export_caps (BraseroPlugin *plugin)
 	GSList *caps;
 
 	brasero_plugin_define (plugin,
+	                       "file-downloader",
 			       /* Translators: this is the name of the plugin
 				* which will be translated only when it needs
 				* displaying. */
@@ -921,6 +922,7 @@ brasero_local_track_export_caps (BraseroPlugin *plugin)
 				       BRASERO_AUDIO_FORMAT_UNDEFINED|
 	                               BRASERO_AUDIO_FORMAT_DTS|
 				       BRASERO_AUDIO_FORMAT_RAW|
+				       BRASERO_AUDIO_FORMAT_RAW_LITTLE_ENDIAN|
 				       BRASERO_VIDEO_FORMAT_UNDEFINED|
 				       BRASERO_VIDEO_FORMAT_VCD|
 				       BRASERO_VIDEO_FORMAT_VIDEO_DVD|
@@ -934,6 +936,7 @@ brasero_local_track_export_caps (BraseroPlugin *plugin)
 				       BRASERO_AUDIO_FORMAT_UNDEFINED|
 	                               BRASERO_AUDIO_FORMAT_DTS|
 				       BRASERO_AUDIO_FORMAT_RAW|
+				       BRASERO_AUDIO_FORMAT_RAW_LITTLE_ENDIAN|
 				       BRASERO_VIDEO_FORMAT_UNDEFINED|
 				       BRASERO_VIDEO_FORMAT_VCD|
 				       BRASERO_VIDEO_FORMAT_VIDEO_DVD|
