@@ -1921,8 +1921,6 @@ brasero_data_disc_rename_activated (BraseroDataDisc *disc)
 						      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 						      _("_Rename"), GTK_RESPONSE_APPLY,
 						      NULL);
-		gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-
 		rename = brasero_rename_new ();
 		brasero_rename_set_show_keep_default (BRASERO_RENAME (rename), FALSE);
 		gtk_widget_show (rename);
@@ -2243,9 +2241,9 @@ brasero_data_disc_key_released_cb (GtkTreeView *tree,
 	if (priv->editing)
 		return FALSE;
 
-	if (event->keyval == GDK_KP_Delete || event->keyval == GDK_Delete)
+	if (event->keyval == GDK_KEY_KP_Delete || event->keyval == GDK_KEY_Delete)
 		brasero_data_disc_delete_selected (BRASERO_DISC (self));
-	else if (event->keyval == GDK_F2)
+	else if (event->keyval == GDK_KEY_F2)
 		brasero_data_disc_rename_activated (self);
 
 	return FALSE;
