@@ -112,22 +112,25 @@ brasero_playlist_get_proportion (BraseroLayoutObject *object,
 {
 	GtkRequisition requisition;
 
-	gtk_widget_size_request (BRASERO_PLAYLIST (object)->priv->button_add->parent,
-				 &requisition);
+	gtk_widget_get_preferred_size (gtk_widget_get_parent (BRASERO_PLAYLIST (object)->priv->button_add),
+				 &requisition, NULL);
 	(*footer) = requisition.height + BRASERO_PLAYLIST_SPACING;
 }
 
 static void
 brasero_playlist_increase_activity_counter (BraseroPlaylist *playlist)
 {
-	if (!GTK_WIDGET (playlist->priv->tree)->window)
+	GdkWindow *window;
+
+	window = gtk_widget_get_window (GTK_WIDGET (playlist->priv->tree));
+	if (!window)
 		return;
 
 	if (playlist->priv->activity_counter == 0) {
 		GdkCursor *cursor;
 
 		cursor = gdk_cursor_new (GDK_WATCH);
-		gdk_window_set_cursor (GTK_WIDGET (playlist->priv->tree)->window,
+		gdk_window_set_cursor (window,
 				       cursor);
 		gdk_cursor_unref (cursor);
 	}
@@ -137,15 +140,17 @@ brasero_playlist_increase_activity_counter (BraseroPlaylist *playlist)
 static void
 brasero_playlist_decrease_activity_counter (BraseroPlaylist *playlist)
 {
+	GdkWindow *window;
+
 	if (playlist->priv->activity_counter > 0)
 		playlist->priv->activity_counter--;
 
-	if (!GTK_WIDGET (playlist->priv->tree)->window)
+	window = gtk_widget_get_window (GTK_WIDGET (playlist->priv->tree));
+	if (!window)
 		return;
 
 	if (playlist->priv->activity_counter == 0)
-		gdk_window_set_cursor (GTK_WIDGET (playlist->priv->tree)->window,
-				       NULL);
+		gdk_window_set_cursor (window, NULL);
 }
 
 static void
@@ -203,9 +208,9 @@ brasero_playlist_start_search (BraseroPlaylist *playlist)
 }
 
 static gboolean
-brasero_playlist_expose_event_cb (GtkWidget *widget,
-				  gpointer event,
-				  gpointer null_data)
+brasero_playlist_draw_cb (GtkWidget *widget,
+			  cairo_t *cr,
+			  gpointer null_data)
 {
 	BraseroPlaylist *playlist = BRASERO_PLAYLIST (widget);
 
@@ -573,7 +578,7 @@ brasero_playlist_add_cb (GtkButton *button, BraseroPlaylist *playlist)
 	gint result;
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (playlist));
-	if (!GTK_WIDGET_TOPLEVEL (toplevel))
+	if (!gtk_widget_is_toplevel (toplevel))
 		return;
 
 	dialog = gtk_file_chooser_dialog_new (_("Select Playlist"),
@@ -835,7 +840,7 @@ brasero_playlist_init (BraseroPlaylist *obj)
 }
 
 static void
-brasero_playlist_destroy (GtkObject *object)
+brasero_playlist_destroy (GtkWidget *object)
 {
 	BraseroPlaylist *playlist = BRASERO_PLAYLIST (object);
 
@@ -858,8 +863,8 @@ brasero_playlist_destroy (GtkObject *object)
 		playlist->priv->parse_type = NULL;
 	}
 
-	if (GTK_OBJECT_CLASS (brasero_playlist_parent_class)->destroy)
-		GTK_OBJECT_CLASS (brasero_playlist_parent_class)->destroy (object);
+	if (GTK_WIDGET_CLASS (brasero_playlist_parent_class)->destroy)
+		GTK_WIDGET_CLASS (brasero_playlist_parent_class)->destroy (object);
 }
 
 static void
@@ -878,10 +883,10 @@ static void
 brasero_playlist_class_init (BraseroPlaylistClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GtkObjectClass *gtkobject_class = GTK_OBJECT_CLASS (klass);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
 	object_class->finalize = brasero_playlist_finalize;
-	gtkobject_class->destroy = brasero_playlist_destroy;
+	widget_class->destroy = brasero_playlist_destroy;
 }
 
 static void
@@ -905,8 +910,8 @@ brasero_playlist_new ()
 	obj = BRASERO_PLAYLIST (g_object_new (BRASERO_TYPE_PLAYLIST, NULL));
 
 	g_signal_connect (obj,
-			  "expose-event",
-			  G_CALLBACK (brasero_playlist_expose_event_cb),
+			  "draw",
+			  G_CALLBACK (brasero_playlist_draw_cb),
 			  NULL);
 
 	return GTK_WIDGET (obj);
